@@ -114,12 +114,10 @@ typedef enum {
 	TARGET_COLOR = 200
 } GtkSourceViewDropTypes;
 
-static GtkTargetEntry drop_types[] = {
+static const GtkTargetEntry drop_types[] = {
 	{"application/x-color", 0, TARGET_COLOR}
 };
 
-static gint n_drop_types = sizeof (drop_types) / sizeof (drop_types[0]);
-
 static guint signals[LAST_SIGNAL] = { 0 };
 
 static GObjectClass *parent_class = NULL;
@@ -572,8 +570,8 @@ gtk_source_view_init (GtkSourceView *view)
 	tl = gtk_drag_dest_get_target_list (GTK_WIDGET (view));
 	g_return_if_fail (tl != NULL);
 
-	gtk_target_list_add_table (tl, drop_types, n_drop_types);
-	
+	gtk_target_list_add_table (tl, drop_types, G_N_ELEMENTS (drop_types));
+
 	g_signal_connect (G_OBJECT (view), 
 			  "drag_data_received", 
 			  G_CALLBACK (view_dnd_drop), 
@@ -2079,8 +2077,7 @@ gtk_source_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
 	view = GTK_SOURCE_VIEW (widget);
 	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
 
-	if ((event->button == 1) &&
-	    view->priv->show_line_numbers &&
+	if (view->priv->show_line_numbers &&
 	    (event->window == gtk_text_view_get_window (GTK_TEXT_VIEW (view),
 						       GTK_TEXT_WINDOW_LEFT)))
 	{
@@ -2094,7 +2091,7 @@ gtk_source_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
 					     y_buf,
 					     NULL);
 	
-		if (event->type == GDK_BUTTON_PRESS)
+		if (event->type == GDK_BUTTON_PRESS && (event->button == 1))
 		{
 			if ((event->state & GDK_CONTROL_MASK) != 0)
 			{
@@ -2112,11 +2109,12 @@ gtk_source_view_button_press_event (GtkWidget *widget, GdkEventButton *event)
 				gtk_text_buffer_place_cursor (buf, &line_start);
 			}
 		}
-		else if (event->type == GDK_2BUTTON_PRESS)
+		else if (event->type == GDK_2BUTTON_PRESS && (event->button == 1))
 		{
 			select_line (buf, &line_start);
 		}
 
+		/* consume the event also on right click etc */
 		return TRUE;
 	}
 
